extern crate sfml;
extern crate rusty;

use std::time::{
    Instant,
    Duration,
};

use sfml::window::{
    ContextSettings,
    Style,
    Event,
    Key,
};

use sfml::graphics::{
    RenderWindow,
    RenderTarget,
    Color,
};

use rusty::engine::scene::Scene;
use rusty::engine::character::Character;
use rusty::engine::controls::Controls;

fn main() {
    let game_width = 800;
    let game_height = 600;

    let mut character = Character::with_controls(Controls::new());
    character.set_position((300.0, 200.0));

    let mut scene = Scene::new();
    scene.add(character);
    scene.add(Character::new());

    let context_settings = ContextSettings {
        ..Default::default()
    };

    let mut window = RenderWindow::new(
        (game_width, game_height),
        "Free Rusty Maker",
        Style::CLOSE,
        &context_settings,
    );

    window.set_framerate_limit(60);

    let mut running = true;

    loop {

        // Manage the events
        while let Some(event) = window.poll_event() {

            match event {
                // Quit the game if window is closed
                Event::Closed => running = false,

                // Quit the game if escape is pressed
                Event::KeyPressed {
                    code: Key::Escape, ..
                } => running = false,

                _ => (),
            }


            scene.manage_event(&event);
        }

        // Manage the physics
        // ...


        // Do the rendering
        window.clear(&Color::rgb(50, 200, 50));
        window.draw(&scene);

        // Display and manage the frame rate
        window.display();

        if ! running {
            break;
        }

    }

}
